<p align="center">
<img width="75%" height="75%" src="https://elehcimd.github.io/cumulative/assets//img/logo-wide-black.svg" alt="Cumulative Logo">
</p>

<p align="center">
<img src="https://elehcimd.github.io/cumulative/assets/img/badges/test.svg" alt="Test">
<img src="https://elehcimd.github.io/cumulative/assets//img/badges/coverage.svg" alt="Coverage">
<img src="https://elehcimd.github.io/cumulative/assets//img/badges/python.svg" alt="Python">
<img src="https://elehcimd.github.io/cumulative/assets//img/badges/pypi.svg" alt="PyPi">
<img src="https://elehcimd.github.io/cumulative/assets//img/badges/license.svg" alt="License">
<img src="https://elehcimd.github.io/cumulative/assets//img/badges/code-style.svg" alt="Code style">
</p>

---

<h1 align="center">
Manipulate and Visualize Time Series Collections
</h1>

An open-source Python library for Data Scientists to efficiently manipulate collections of time series data. Features include data loading, transformation, persistence, and visualization.

---

* **Documentation**: [https://elehcimd.github.io/cumulative](https://elehcimd.github.io/cumulative)
* **Source code**: [https://github.com/elehcimd/cumulative](https://github.com/elehcimd/cumulative) (License: [BSD 3-Clause](https://elehcimd.github.io/cumulative/license/))
* **Discussions**: [Ask questions, share ideas, engage](https://github.com/elehcimd/cumulative/discussions)
* **Funding**: You can [star](https://github.com/elehcimd/cumulative) the project on GitHub and [hire me](https://www.linkedin.com/in/dallachiesa/) to make sense of your time series.

---

